# Branched video player

If you use our code or software in your research, please include a reference to our ACM MM 2019 paper:

Eric Lindskog, Jesper Wrang, Madeleine Backstrom, Linn Hallonqvist, and Niklas Carlsson, "Generalized Playback Bar for Interactive Branched Video", Proc. ACM International Conference on Multimedia (ACM MM), Nice, France, Oct. 2019.

# Quickstart

To run the video player you'll need 2 servers running, 1 to serve the video files and 1 for building the frontend code.

Install [Node.js](https://nodejs.org/en/), then install the dependencies for both Dash.js and for this project:
```bash
cd video-player
npm install

# Dash.js depenencies
cd dash-js
npm install

cd ..
npm start
```

The other server serving the video content can be any type of server that can serve a folder. The server should serve the folder `videos/dash` and use port 9000.

We have a simple implemention of that server in Go, with precompiled binaries for Windows and Ubuntu in the folder `server`.

If you already have Python 3 installed, you could use that instead with the following command: 
```bash
cd videos/dash
python3 -m http.server 9000
```

# Project overview
Here's a short summary of the files for the frontend code in `video-player/src`:

* **index.js** - The main file being run. It imports the other modules from the application.
* **branchedPlayer.js** - Creates the video player using dash.js. Does basic setup and starts the main loop for the video player.
* **playbackBar.js** - Does setup of the playback bar for the video player. Contains all logic for drawing the different implementations of the playback bars.
* **state.js** - Contains the settings for the player. Also holds a reference to the current state of the video player, e.g. the current branch and time etc. 
* **branchButtons.js** - Here's the logic for the buttons that appear when a branch point is hit.
* **gutwinsFisheye/index.js** - Handles the mathematical parts of the fisheye effect used in some playback bar implementations. 
* **shapes/\*** - Some helper methods for drawing on the canvas.
