import {state, findBranchByID} from './state'
import player from './branchedPlayer'
//const buttonBox = document.getElementById('buttons')
const overlayedButtons = document.getElementById('overlayedButtons')
const canvasButtons = document.getElementById('canvasButtons')
const choiceDistance = 10
const branchMargin = 0.5

export function updateButtons () {
  const {timeForBranch, nextBranch} = state

  // Upcoming branch and user has not made a choice yet
  if (timeForBranch < choiceDistance && !nextBranch) {
    const {useOverlayButtons, useCanvasButtons} = state
    if (useOverlayButtons && overlayedButtons.children.length === 0) {
      createOverlayedButtons()
    }
    else if(useCanvasButtons && canvasButtons.children.length === 0) {
       createCanvasButtons()
    }
  }

  // Reached a branch and has not made a choice yet
  if (timeForBranch < branchMargin && !nextBranch) {
    if (!player.isPaused()) {
      player.pause()
    }
  }

  // Reached a branch and has made a choice
  if (timeForBranch < branchMargin && nextBranch) {
    const branch = findBranchByID(nextBranch)
    state.nextBranch = null
    player.seek(branch.startTime + branchMargin)

    if (player.isPaused()) {
      player.play()
    }
  }
}


function createOverlayedButtons() {
  const {upcomingBranches, matchWithLetters,isHighlight,drawLetters} = state
  upcomingBranches.forEach((branchID) => {
    const branch = findBranchByID(branchID)
    const button = document.createElement('button')
    drawLetters[branchID] = true
    button.className = 'overlayButton'
    button.onclick = () => {
      state.nextBranch = branchID
      clearButtons()
      //state.isHighlight = {}
      //state.drawLetters= {}
    }
    button.onmouseenter = function () {
      isHighlight[branchID]= true
      button.style.borderColor = '#02bfff'
    }
    button.onmouseleave = function () {
      isHighlight[branchID]= false
      button.style.borderColor = '#000000'
    }
    if(matchWithLetters) button.innerHTML = branch.id +": "  + branch.displayName
    else button.innerHTML = branch.displayName
    overlayedButtons.appendChild(button)
  })

}
function createCanvasButtons() {
  const {upcomingBranches, matchWithLetters,drawLetters,isHighlight} = state

  var nrOfBranches = upcomingBranches.length
  var height = Math.floor(canvasButtons.clientHeight/(nrOfBranches*(1.2)))
  upcomingBranches.forEach((branchID) => {
    const branch = findBranchByID(branchID)
    const button = document.createElement('button')
    button.className = 'canvasButton'
    button.style.height = height +"px"
    button.style.width = "50%"
    button.style.marginTop = height /10 +"px"
    button.style.marginBottom = height /10 +"px"
    button.style.fontSize = height*0.6+"px"
    button.onclick = () => {
      state.nextBranch = branchID
      clearButtons()
    }
    button.onmouseenter = function () {
      isHighlight[branchID]= true
      button.style.borderColor = '#02bfff'
    }
    button.onmouseleave = function () {
      isHighlight[branchID]= false
      button.style.borderColor = '#000000'
    }
    if(matchWithLetters){
      button.innerHTML = branch.id +": "  + branch.displayName
      drawLetters[branchID] = true

    }
    else button.innerHTML = branch.displayName
    canvasButtons.appendChild(button)
  })

}

export function clearButtons () {
  state.isHighlight = {}
  state.drawLetters= {}
  overlayedButtons.innerHTML = ''
  canvasButtons.innerHTML = ''
}
