import {Point, fishRadius} from './index'

// Round circle that represents a branch point where the user can make a choice
export class BranchPoint {
  constructor (x, y, id,radius = 4) {
    this.point = new Point(x, y)
    this.radius = radius
    this.id = id
  }

  // Draw a non-fisheyed circle
  draw (ctx) {
    fillCircle(ctx, this.point, this.radius, 'black')
    fillCircle(ctx, this.point, this.radius * 0.8, 'white')
  }

  // Draw a distorted fisheyed circle according to a center point
  drawFisheye (ctx, fisheyePoint) {
    fillFisheyeCircle(ctx, this.point, fisheyePoint, this.radius, 'black')
    fillFisheyeCircle(ctx, this.point, fisheyePoint, this.radius * 0.8, 'white')
  }
}

export class FishLens {
  constructor (x, y, radius) {
    this.point = new Point(x, y)
    this.radius = fishRadius
  }

  // Draw a non-fisheyed circle
  draw (ctx) {
    strokeCircle(ctx, this.point, this.radius)
  }
}

function strokeCircle (ctx, centerPoint, radius, color = '#111') {
  ctx.strokeStyle = color
  ctx.lineWidth = 2

  ctx.beginPath()
  ctx.arc(centerPoint.x, centerPoint.y, radius, 0, 2 * Math.PI)
  ctx.stroke()
}

function fillCircle (ctx, centerPoint, radius, color = '#111') {
  ctx.fillStyle = color

  ctx.beginPath()
  ctx.arc(centerPoint.x, centerPoint.y, radius, 0, 2 * Math.PI)
  ctx.fill()
}

function fillFisheyeCircle (ctx, centerPoint, fisheyePoint, radius, color = '#111') {
  const {x, y, scale} = centerPoint.fisheye(fisheyePoint)
  ctx.fillStyle = color

  const scaleLimit = Math.min(scale, 2)
  ctx.beginPath()
  ctx.arc(x, y, radius * scaleLimit, 0, 2 * Math.PI)
  ctx.fill()
}
